@@ -11,7 +11,7 @@ from pymonetdb import mapi
 from pymonetdb.exceptions import OperationalError
 
 
-class ProfilerConnection(object):
+class ProfilerConnection:
     """
     A connection to the MonetDB profiler.
     """
@@ -28,7 +28,7 @@ class ProfilerConnection(object):
         self._mapi.cmd("profiler.setheartbeat(%d);\n" % heartbeat)
         try:
             self._mapi.cmd("profiler.openstream();\n")
-        except OperationalError as e:
+        except OperationalError:
             # We might be talking to an older version of MonetDB. Try connecting
             # the old way.
             self._mapi.cmd("profiler.openstream(3);\n")
@@ -39,3 +39,8 @@ class ProfilerConnection(object):
             self._buffer += self._mapi._getblock()
 
         return self._buffer[:-1]
+
+    def close(self):
+        if self._mapi:
+            self._mapi.disconnect()
+            self._mapi = None
